//
//  ETTrackingPageView.h
//  EcondaTracking
//
//  Copyright (c) 2002-2011  econda GmbH Karlsruhe
//  All rights reserved.
//

#import <Foundation/Foundation.h>
#import "ETBasketItem.h"


typedef enum {
	ETTargetRuleUseMonitorDefaultSettings = 0,
	ETTargetRuleUseOnlyFirstFromSession,
    ETTargetRuleAll
} ETTargetRule;



/**
 * This is the representation of a view.
 * After creation of a new ETTrackingPageView, you can add several properties.
 * Afterwards you should add the pageView to a ETTrackingSession and perhaps submit the collected data of the session.
 */

@interface ETTrackingPageView : NSObject

/**----------------------------------------------------
 * @name Adding Properties to a page view
 * ---------------------------------------------------
 */

/** Adds a billing property
 
 @param billingId unique identifier for this bill
 @param customerId unique identifier for this customer
 @param total the total sum of this bill!
 @param country the country of the customer
 @param cip the cip of the customer
 @param city the city of the customer
 */

- (void)addBilling:(NSString*)billingId customerId:(NSString*)customerId total:(double)total country:(NSString*)country cip:(NSString*)cip city:(NSString*)city;


/** Adds a contact property
 
 @param contactType type of the contact-form used
 */

- (void)addContact:(NSString*)contactType;


/** Adds a content property
 
 @param content a content-label for this page
 */

- (void)addContent:(NSString*)content;


/** Adds a country property. Some shop systems can handle multiple sites. If we have to distinguish them, we set the countryId for the actual shop.
 
 @param countryId unique identifier for this country
 */

- (void)addCountryId:(NSString*)countryId;


/** Adds a download property
 
 @param label a download-label for this page
 */

- (void)addDownload:(NSString*)label;


/** Adds a language property. Some shop systems can handle multiple languages. If we have to distinguish them, we set the language.
 
 @param langId unique identifier for this language
 */

- (void)addLangId:(NSString*)langId;


/** Adds a login property. We encrypt (generate md5-Hash) the userId to implement the German "Datenschutzgesetz" in this Method
 
 @param userId UserID or email - must be a unique identifier
 @param result result 0 if succes, positive int for error numbers
 */

- (void)addLogin:(NSString*)userId result:(int)result;


/** Adds a property for marketing channel ('source')
 
 @param marketingChannel a marketing channel
 */

- (void)addMarketingChannel:(NSString*)marketingChannel;


/** Adds a orderProcess property.
 
 @param processStep a Label to identify the step in the order-process by convention this is a positive int followed by an underscore and the label e.g. "1_Kundendaten", "2_Zahlungsoptionen", ...
 */

- (void)addOrderProcess:(NSString*)processStep;


/** Adds a pageId property. pageId is used by Clickmonitor to distinguish Pages
 
 @param pageId unique identifier for this page
 */

- (void)addPageId:(NSString*)pageId;


/** Adds a addToBasket - Event to this page
 
 @param item the ETBasketItem this Event belongs to
 */

- (void)addProductAddToBasket:(ETBasketItem*)item;


/** Adds a ec_Event property. Stored as array of array. Array contains the eventType = 'buy' and all ETBasketItem-Informations.
 
 @param item ETBasketItem
 */

- (void)addProductBuy:(ETBasketItem*)item;


/** Adds a ec_Event property. Stored as array of array. Array contains the eventType = 'buy' and all BasketItem-Informations.
 
 @param basket Array of ETBasketItems
 */

- (void)addProductBuyList:(NSArray*)basket;


/** Adds a ec_Event property with custom eventType. Stored as array of array. Array contains the custom eventType and all ETBasketItem-Informations.
 
 @param item the item the EC-Event belongs to
 @param eventType type of the event like c_add, c_rmv, view, buy
 */

- (void)addProductCustomEvent:(ETBasketItem*)item eventType:(NSString*)eventType;


/** Adds a removeFromBasket - Event to this page
 
 @param item the ETBasketItem this Event belongs to
 */

- (void)addProductRemoveFromBasket:(ETBasketItem*)item;


/** Adds a ec_Event property. Stored as array of array. Array contains the eventType = 'view' and all BasketItem-Informations.
 
 @param item ETBasketItem this detail View belongs to
 */

- (void)addProductView:(ETBasketItem*)item;


/** Adds a custom boolean property
 
 @param key key
 @param value value
 */

- (void)addProperty:(NSString*)key boolValue:(BOOL)value;


/** Adds a custom number property
 
 @param key key
 @param value value
 */

- (void)addProperty:(NSString*)key numberValue:(NSNumber*)value;


/** Adds a custom string property
 
 @param key key
 @param value value
 */

- (void)addProperty:(NSString*)key stringValue:(NSString*)value;


/** Adds a custom array property
 
 @param key key
 @param array array
 */

- (void)addPropertyArray:(NSString*)key array:(NSArray*)array;


/** Adds a custom array of arrays property
 
 @param key key
 @param arrays arrays
 */

- (void)addPropertyArrays:(NSString*)key array:(NSArray*)arrays;


/** Adds a register property. This method encrypts the userId to implement the German "Datenschutzgesetz"
 
 @param userId UserID or email must be a unique identifier
 @param result result code 0 if success positive int for error numbers
 */

- (void)addRegister:(NSString*)userId result:(int)result;


/** Adds a search property
 
 @param queryString the search string
 @param numberOfHits the number of hits found
 */

- (void)addSearch:(NSString*)queryString numberOfHits:(int)numberOfHits;


/** Adds a siteid property. Some shop systems can handle multiple sites. If we have to distinguish them, we set the siteid for the actual shop.
 
 @param siteId unique identifier for this site
 */

- (void)addSiteId:(NSString*)siteId;


/** Adds a target property.
 
 @param target Name for this Target, e.g. download, lottery
 @param additionalInfo additional Information, e.g. the Name of the downloaded Document
 @param score Your value of this target (used for calculation of conversationrate)
 @param rule Method to use. Only first of session, all or usage of default value configured in econda-monitor
 */

- (void)addTarget:(NSString*)target additionalInfo:(NSString*)additionalInfo score:(double)score targetRule:(ETTargetRule)rule;

- (BOOL)hasProperty:(NSString*)key;
- (NSString*)JSONString;
- (NSString*)description;


@end
